@@ -66,12 +66,7 @@ class PersistentAnnotator(Annotator):
             if len(self.labeled_examples) == 0 or n_changes / len(self.labeled_examples) > 0.2:
                 # so many duplication, optimize the log
                 self.logger.debug("Optimizing existing output file as it contains many duplications...")
-                with open(output_file + ".tmp", "w") as f:
-                    writer = csv.writer(f, delimiter='\t', quoting=csv.QUOTE_MINIMAL)
-                    for example_id, class_id in self.labeled_examples.items():
-                        writer.writerow([example_id, class_id])
-
-                os.rename(output_file + ".tmp", output_file)
+                self.optimize_annotator_logs()
             self.logger.debug("Finish loading output file...")
 
     def persist_changes(self, changes: List[Tuple[str, Optional[str]]]):
@@ -87,6 +82,16 @@ class PersistentAnnotator(Annotator):
                     self.labeled_examples[example_id] = class_id
                 writer.writerow([example_id, class_id])
 
+    def optimize_annotator_logs(self):
+        with open(self.output_file + ".tmp", "w") as f:
+            writer = csv.writer(f, delimiter='\t', quoting=csv.QUOTE_MINIMAL)
+            for example_id, class_id in self.labeled_examples.items():
+                writer.writerow([example_id, class_id])
+
+        os.rename(self.output_file, self.output_file + ".backup")
+        os.rename(self.output_file + ".tmp", self.output_file)
+        os.remove(self.output_file + ".backup")
+
     def get_label(self, example_id) -> str:
         return self.labeled_examples[example_id]
 
